getModel (see details).## S3 method for class 'baseGmm.twoStep':
momentEstim(object, ...)
## S3 method for class 'baseGmm.twoStep.formula':
momentEstim(object, ...)
## S3 method for class 'baseGmm.iterative.formula':
momentEstim(object, ...)
## S3 method for class 'baseGmm.iterative':
momentEstim(object, ...)
## S3 method for class 'baseGmm.cue.formula':
momentEstim(object, ...)
## S3 method for class 'baseGmm.cue':
momentEstim(object, ...)getModelmomentEstim is applied to an other class objectgmm. By default, it is of class baseGmm.res. It estimates the model and organize the results that will be finalized by the method FinRes. More methods can be created in order to use other GMM methods not yet included in the package.Hansen, L.P. and Heaton, J. and Yaron, A.(1996), Finit-Sample Properties of Some Alternative GMM Estimators. Journal of Business and Economic Statistics, 14 262-280.