Learn R Programming

gmm (version 1.5-0)

vcov: Variance-covariance matrix of GMM or GEL

Description

It extracts the matrix of variances and covariances from gmm or gel objects.

Usage

## S3 method for class 'gmm':
vcov(object, ...)
## S3 method for class 'gel':
vcov(object, lambda = FALSE, ...)
## S3 method for class 'tsls':
vcov(object, type=c("Classical","HC0","HC1","HAC"), hacProp = list(), ...)

Arguments

object
An object of class gmm or gmm returned by the function gmm or gel
lambda
If set to TRUE, the covariance matrix of the Lagrange multipliers is produced.
type
Type of covariance matrix for the meat
hacProp
A list of arguments to pass to kernHAC
...
Other arguments when vcov is applied to another class object

Value

  • A matrix of variances and covariances

Details

For tsls(), if vcov is set to a different value thand "Classical", a sandwich covariance matrix is computed.

Examples

Run this code
# GMM #
n = 500
phi<-c(.2,.7)
thet <- 0
sd <- .2
x <- matrix(arima.sim(n = n,list(order = c(2,0,1), ar = phi, ma = thet, sd = sd)), ncol = 1)
y <- x[7:n]
ym1 <- x[6:(n-1)]
ym2 <- x[5:(n-2)]

H <- cbind(x[4:(n-3)], x[3:(n-4)], x[2:(n-5)], x[1:(n-6)])
g <- y ~ ym1 + ym2
x <- H

res <- gmm(g, x)
vcov(res)

## GEL ##

t0 <- c(0,.5,.5)
res <- gel(g, x, t0)
vcov(res)
vcov(res, lambda = TRUE)

Run the code above in your browser using DataLab